@@ -282,6 +282,7 @@ class Sale(
     @classmethod
     def __setup__(cls):
         super(Sale, cls).__setup__()
+        cls.create_date.select = True
         cls._order = [
             ('sale_date', 'DESC NULLS FIRST'),
             ('id', 'DESC'),
@@ -364,9 +365,6 @@ class Sale(
         # Migration from 4.0: Drop not null on payment_term
         table.not_null_action('payment_term', 'remove')
 
-        # Add index on create_date
-        table.index_action('create_date', action='add')
-
         # Migration from 5.6: rename state cancel to cancelled
         cursor.execute(*sql_table.update(
                 [sql_table.state], ['cancelled'],
@@ -1420,10 +1418,10 @@ class SaleLine(TaxableMixin, sequence_ordered(), ModelSQL, ModelView):
 
     @fields.depends('moves', methods=['planned_shipping_date'])
     def on_change_with_shipping_date(self, name=None):
-        if self.moves:
+        moves = [m for m in self.moves if m.state != 'cancelled']
+        if moves:
             dates = filter(
-                None, (m.effective_date or m.planned_date for m in self.moves
-                    if m.state != 'cancelled'))
+                None, (m.effective_date or m.planned_date for m in moves))
             return min(dates, default=None)
         return self.planned_shipping_date
 
